#
# spec file for package python-textfsm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-textfsm
Version:        1.1.3
Release:        4.4
Summary:        Python module for parsing semi-structured text into python tables
License:        Apache-2.0
URL:            https://github.com/google/textfsm
Source:         https://github.com/google/textfsm/archive/v%{version}.tar.gz#/textfsm-%{version}.tar.gz
# PATCH-FIX-OPENSUSE https://github.com/google/textfsm/issues/118
Patch0:         correct-version.patch
# https://github.com/google/textfsm/commit/c8843d69daa9b565fea99a0283ad13c324d5b563
Patch1:         python-textfsm-no-python2.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
Python module which implements a template based state machine for parsing
semi-formatted text. Originally developed to allow programmatic access to
information returned from the command line interface (CLI) of networking
devices.

%prep
%autosetup -p1 -n textfsm-%{version}
# drop shebang
sed -i -e '/^#!\//, 1d' textfsm/*.py

%build
%pyproject_wheel

%install
%pyproject_install
# don't install broken textfsm wrapper binary
%python_expand rm -f %{buildroot}%{_bindir}/textfsm
# or the testdata
%python_expand rm -r %{buildroot}%{$python_sitelib}/testdata
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license COPYING
%doc README.md
%{python_sitelib}/textfsm
%{python_sitelib}/textfsm-%{version}.dist-info

%changelog
* Mon Jan 29 2024 pgajdos@suse.com
- do not require six
- deleted patches
  - remove-future-requirement.patch (part of python-textfsm-no-python2.patch)
- added patches
  fix https://github.com/google/textfsm/commit/c8843d69daa9b565fea99a0283ad13c324d5b563
  + python-textfsm-no-python2.patch
* Tue Sep  5 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch correct-version.patch, version in the tarball does not match.
- Add patch remove-future-requirement.patch, drop requirement of future
- Switch to pyproject and autosetup macros
- Clean up python 2 leftovers
- Do not install testdata
- Stop using greedy globs in %%files
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Jan 29 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.3:
  * Fix to mismatched parenthesis.
* Tue Dec  7 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Mon Jul 19 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * String handling fix for Windows platforms
* Sun Dec 20 2020 ecsos <ecsos@opensuse.org>
- Remove Conflicts: python-texttable because it should fixed since
  version 1.0.0. https://github.com/google/textfsm/issues/77
  texttable.py is now in subdir textfsm.
* Tue Nov 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.1
  * Fix parsing of value string to allow mismatched parenthesis
    inside [] brackets.
  * Improve readability of value parse fix.
  * Added additional test.
  * Soft fail when fcntl is missing, fallback to default screen size.
* Thu Aug  1 2019 pgajdos@suse.com
- require future for python2
* Wed Jul 31 2019 pgajdos@suse.com
- version update to 1.1.0
  * Per 'http://python-future.org/automatic_conversion.html' py2 & py3 compatibility.
  * Make sure test fails if there is more than one list entry.
  * Fix deprecated warning for invalid escapes.
  * Support utf-8 in template files
  * Add utf-8 characters to a test example
  * Unicode example in template input.
  * Switch to utf-8 strings and remove unnecessary conversions.
  * Remove legacy lint checks
  * Migrate StringIO and remove unneeded import six.
  * Remove unnecessary explicit unicast declaration.
  * oll back changes to 'open'.
  * Cosmetic linting.
  * Package 'future' needed for importing builtins.
  * Add tests and testdata to distribution.
  * Use correct install_requires stanza for dependencies.
  * Include testdata files in binarty dist for tyesting.
- deleted patches
  - textfsm_test_do_not_relay_on_dic_order.patch (upstreamed)
* Fri Jul 20 2018 tchvatal@suse.com
- Conflict with texttable as we provide same package file
  reported on GH for upstream to sort out
* Mon Jul  2 2018 aplanas@suse.com
- Add textfsm_test_do_not_relay_on_dic_order.patch to enable
  tests in Python2 and Python3
* Thu Jun 21 2018 tchvatal@suse.com
- Add dependency over python-six as it is stated by upstream
- Switch to github archive as it contains the testdata
* Wed Jun 20 2018 gyee@suse.com
- Remove python-devel requirement as it is not needed.
* Wed Jun 20 2018 gyee@suse.com
- Remove useless descriptions.
* Wed Jun 20 2018 gyee@suse.com
- Regenerate the spec file using py2pack.
* Tue Jun 19 2018 gyee@suse.com
- Fix SingleSpec requirements.
* Tue Jun 19 2018 gyee@suse.com
- Make it a SingleSpec package.
* Mon Jun 18 2018 gyee@suse.com
- create initial package version 0.4.1:
  Pulled from https://files.pythonhosted.org/packages/a1/0d/a1b490503545b3b4600b965eae5d44cc2b6ce27cfb44f4debc563dbb56d3/textfsm-0.4.1.tar.gz
